<?php
/**
 * Add image sizes to theme
 *
 * @since 0.1.17
 *
 */

class UBC_CLF_Lite_Theme_Support {

	/**
	 * Set up filter hooks for main html tag classes
	 *
	 * @since 1.0.0
	 *
	 */
	public function init() {
		// add_action( 'after_setup_theme', array( $this, 'wp_clf_lite_remove_header_theme_support_then_add_back' ) );
		add_filter( 'wp_clf_lite_custom_header_setup', array( $this, 'wp_clf_lite_custom_header_setup_ext' ) );
		add_action( 'wp_clf_lite_course_section_open_close_accordion', array( $this, 'get_course_section_accordion_open_close_button' ) );
		add_action( 'course_sections_navigation', array( $this, 'get_course_sections_navigation' ) );

	}


	public function wp_clf_lite_custom_header_setup_ext( ) {

		$args = array(

			'default-image'          => '',
			'default-text-color'     => '000000',
			'width'                  => 1440,
			'height'                 => 400,
			'flex-height'            => true,
			'wp-head-callback'       => 'wp_clf_lite_header_style',
			'admin-head-callback'    => 'wp_clf_lite_admin_header_style',
			'admin-preview-callback' => 'wp_clf_lite_admin_header_image',

		);

		return $args;

	}

	/**
	 * get_course_title() function gets either the site title or the theme mod title raw
	 * 
	 * @since 0.1.39
	 *
	 * @param string $site_title
	 * @param string $course_title string
	 * @param string $get_course_title
	 * 
	 * @return string $get_course_title
	 */
	public function get_course_title() {

		$site_title 	  = get_bloginfo( 'name' );
		$course_title	  = get_theme_mod( 'course_title' );
		$get_course_title = ! empty( $course_title ) ? $course_title : $site_title;

			return esc_html( $get_course_title );

	}

	/**
	 * course_title() function gets either the site title or the theme mod title with a before or after for tag elements
	 * 
	 * @since 0.1.39
	 *
	 * @param string $site_title = UBC_CLF_Lite_Theme_Support::get_course_title()
	 * @param string $before html tag opening
	 * @param string $after  html tag closing
	 * 
	 * @return string $course_title
	 */
	public function course_title( $before = '', $after = '' ) {

		$site_title = UBC_CLF_Lite_Theme_Support::get_course_title();

		if ( empty( $site_title ) )
			return;

		$course_title = $before . $site_title . $after;

			echo wp_kses_post( $course_title );

	}

	/**
	 * get_course_description() function gets the course description
	 * 
	 * @since 0.1.39
	 *
	 * @param string $course_description 
	 * 
	 * @return string $course_description 
	 */

	 public function get_course_description() {

		$course_description = ( ! empty( get_theme_mod( 'course_decription' ) ) ? get_theme_mod( 'course_decription' ) : '' );

			return esc_html( get_theme_mod( 'course_decription' ) );

	 }

	/**
	 * course_description() function gets the course description with before and after tags
	 * 
	 * @since 0.1.39
	 *
	 * @param string $get_course_description = UBC_CLF_Lite_Theme_Support::get_course_description();
	 * @param string $before - html tag before
	 * @param string $after - html tag after
	 * 
	 * @return string $course_description 
	 */

	 public function course_description( $before = '', $after = '' ) {

		$get_course_description = UBC_CLF_Lite_Theme_Support::get_course_description();

		if ( empty( $get_course_description ) ) :

			return;

		else:

			$course_description = $before . $get_course_description . $after;
			echo wp_kses_post( $course_description );

		endif;

	 }

	/**
	 * get_course_section_accordion_open_close_button() display accoridion button if website has sections
	 * 
	 * @since 0.1.39
	 *
	 * @param boolean $has_section - function from UBC PRESS if has posts in section post type
	 * 
	 * @return string template
	 */

	 public function get_course_section_accordion_open_close_button() {

		$has_section = \UBC\Press\Utils::course_has_section();

		if ( empty( $has_section )  ) :

			return;

		else :

			require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/expand-collapse-accordion.php' );

		endif;
		
	 }

	/**
	 * get_faculty_unit_title() return a raw text version of the selected faculty
	 * 
	 * @since 0.1.39
	 *
	 * @param array $stakeholder
	 * @param array $faculty_list
	 * 
	 * @return string $faculty_list[ $stakeholder ];
	 */

	 public function get_faculty_unit_title() {

		if ( empty( get_theme_mod( 'faculty_school' ) ) )
			return;

		$stakeholder  = get_theme_mod( 'faculty_school', '' );
		$faculty_list = \UBC\Press\Utils::get_faculty_list();

			return $faculty_list[ $stakeholder ];

	 }

	/**
	 * faculty_unit_title() return faculty title with ability to add html tags
	 * 
	 * @since 0.1.39
	 *
	 * @param string $get_faculty - UBC_CLF_Lite_Theme_Support::get_faculty_unit_title()
	 * @param string $faculty
	 * 
	 * @return string $faculty - faculty title
	 */

	 public function faculty_unit_title( $before = '', $after = ''  ) {

		$get_faculty = UBC_CLF_Lite_Theme_Support::get_faculty_unit_title();

		if ( empty( $get_faculty ) )
			return;

			$faculty = $before . $get_faculty . $after;
			echo wp_kses_post( $faculty );

	 }

	/**
	 * get_course_sections_navigation() do action to display course navigation
	 * 
	 * @since 0.1.39
	 *
	 * @param array $args - list of arguments
	 * @param array $get_sections_array = gets all sections based of $args
	 * @param array $sections = gets all sections ids
	 * 
	 * @return string $faculty - faculty title
	 */

	 public function get_course_sections_navigation() {

		// check if website has sections
		$has_section = \UBC\Press\Utils::course_has_section();

		if ( empty( $has_section )  )
			return;

		// get the post id and post parent id.
		global $post;
		$the_post_id = $post->ID;
		$the_post_parent = wp_get_post_parent_id( $the_post_id );

		// arguments for get_posts
		$args = array(
			'post_type' 	=> 'section',
			'sort_column'	=> 'menu_order',
			'sort_order'    => 'asc',
			'exclude'   	=> array( $the_post_parent ),
			'parent'		=> $the_post_parent,
		);

		// get sections
		$get_sections_array = get_pages( $args );

		// set up empty array for section ids
		$sections = array();
		foreach( $get_sections_array as $section ) :
			$sections[] += $section->ID;
		endforeach;

		// get the post ids for the prev and next sections
		$get_current_post_id     = array_search( $the_post_id, $sections );
		$get_previous_section_id = $sections[$get_current_post_id-1];
		$get_next_section_id 	 = $sections[$get_current_post_id+1];

		if ( empty( $get_previous_section_id ) && empty( $get_next_section_id  ))
			return;

		// get prev and next url
		$previous_url = ! empty( $get_previous_section_id ) ? get_permalink( intval( $get_previous_section_id ) ) : '';
		$next_url = ! empty( $get_next_section_id ) ? get_permalink( intval( $get_next_section_id ) ) : '';

		// get prev and next section title
		$get_prev_title = get_the_title( $get_previous_section_id );
		$get_next_title = get_the_title( $get_next_section_id );

		// store it all in an array and pass it to template
		$get_prev_next = array(
			'prev' => array(
				'id'	=> $get_previous_section_id,
				'url'	=> $previous_url,
				'title'	=> $get_prev_title,
			),
			'next' => array(
				'id'	=> $get_next_section_id,
				'url'	=> $next_url,
				'title' => $get_next_title,
			), 
		);

		// get the template path and file ready
		$startPath = trailingslashit( dirname( __FILE__ ) ) . '../template-parts';
		$dashboard_menu_templ = 'single-section-footer-navigation.php';

		// call the template with our data
		\UBC\Helpers::locate_template_part_in_plugin( $startPath, $dashboard_menu_templ, true, false, $get_prev_next );

	 }

	 public function is_local_dev() {

		$starter_path = get_stylesheet_directory();

		if ( file_exists( $starter_path . 'local-dev.php' ) )
			return true;
	 }

}

// Initialize our child theme changes.
add_action( 'after_setup_theme', 'after_setup_theme_ubc_clf_lite_theme_support_class_hooks_init', 15 );


/**
 * Initialize the UBC_CLF_Lite_Customizer class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme_ubc_clf_lite_theme_support_class_hooks_init() {

	$UBC_CLF_Add_Theme_Options = new UBC_CLF_Lite_Theme_Support();
	$UBC_CLF_Add_Theme_Options->init();

}/* after_setup_theme_ubc_clf_lite_theme_support_class_hooks_init() */
